# Client side API

## Events

Most events fired by the matrix classes are relayed to the pivot grid with the prefix "pivot".

## Matrix class

### Abstract matrix

The [Abstract matrix](#!/api/Mz.aggregate.matrix.Abstract) class is the one responsible to 
build the top and left axis items and to calculate the result for each pair left/top item.

If you want to extend a matrix to do your own processing please have a look at the various
template methods that are available. Events are also fired if that's the preferred way.

### Local matrix

If you have a small to medium data set then you can use the [Local matrix](#!/api/Mz.aggregate.matrix.Local)
class to do all calculations in the browser.

    Ext.create('Mz.pivot.Grid', {
        // ...
        matrixConfig: {
            mztype:             'local',
            store:              'YourStore',
            recordsPerJob:      1000,
            timeBetweenJobs:    2
        }
        // ...
    });
    
The Local matrix processes store records in multiple jobs to prevent browser to freeze when
working with a medium data set. You can optionally define how many records should 
be processed per job and what is the delay between jobs (in miliseconds).

If you don't want to set matrix specific configs you can directly attach a store to the
pivot grid since the default matrix configuration is Local.

    Ext.create('Mz.pivot.Grid', {
        // ...
        store: 'YourStore'
        // ...
    });

### Remote matrix

When dealing with large data sets, calculations in the browser can take a lot of time 
so it's better to use the [Remote matrix](#!/api/Mz.aggregate.matrix.Remote). This one will serialize 
all configs and send them back to the server for remote calculations. It expects back 
a JSON response in a specific format.

    Ext.create('Mz.pivot.Grid', {
        // ...
        matrixConfig: {
            mztype:     'remote',
            url:        'http://your-backend-url',
            timeout:    3000    // this is optional and it's used by the Ajax call
        }
        // ...
    });

#### What exactly is sent to the server?

leftAxis, topAxis and aggregate are arrays of [dimension item objects](#!/api/Mz.aggregate.dimension.Item). 
These arrays are serialized and sent as params to the Ajax call.

    params = {
        leftAxis:   leftAxis,
        topAxis:    topAxis,
        aggregate:  aggregate
    };
    // ...
    Ext.Ajax.request({
        // ...
        url:        me.url,
        timeout:    me.timeout,
        jsonData:   params,
        // ...
    });

Before doing the Ajax call additional params are collected via the event "beforerequest"
(which is actually relayed to the grid as "pivotbeforerequest") or via the template
method "onBeforeRequest".

#### What format has the JSON response?

When a [dimension item](#!/api/Mz.aggregate.dimension.Item) is added to the respective config 
an id is generated if this was not provided. This is is very important for the JSON response.

    {
        success: true,
        leftAxis: [{
            key:            '-1276511163',  // that's the crc32 of value "Macromedia"
            value:          'Macromedia',
            // this is the id of the dimension, the one that you provided or was generated
            dimensionId:    'leftAxis1'
        },{
            // when multiple dimensions are provided then the result key should be formatted like this
            key:            '-1276511163/243243',
            value:          'Steve',
            // this is the id of the dimension, the one that you provided or was generated
            dimensionId:    'leftAxis2'
        }],
        topAxis: [{
            // same like leftAxis
        }],
        results: [{
            leftKey:    '-1276511163',
            topKey:     '34535345435',
            values: {
                agg1:   4345.34,    // agg1 is the id of the aggregate dimension
                agg2:   244         // agg2 is the id of the 2nd aggregate dimension defined
            }
        }]
    }
    
Basically you return an array of items for the leftAxis and topAxis and all results
for the left/top item pairs.

Why is the key calculated as crc32? Because internally these keys are used with separators
and no matter how fine you sanitize the strings you can end up with bugs in the process.

"#mzgrandtotal#" is the key configured on the matrix for the grand total calculations. 
You can define your own key on the matrix.grandTotalKey.

If used on both leftKey and topKey it means is the grand total for both axis.

When used for leftKey it means the grand total for columns for each topKey provided.

When used for topKey it means the grand total for rows for each leftKey provided.

#### How do I calculate on the server?

You can either have a look at our php example in the examples folder or you can do your
own implementation. There are various way to do that and in different programming languages.
You could even connect to an OLAP server and get back the results.

If something fails on the server while doing your calculations you can send back
success: false and add any other information to your JSON response. The Remote matrix 
class will recognize that the call failed and will fire the "requestexception" event (which
is relayed to the pivot grid as "pivotrequestexception") and also call the template
method "onRequestException".