# Appearance

## Layout

There are two layout types available so far:

* outline {@img outline.png}
* compact {@img compact.png}

## Totals positioning

On both left and top axis the position of the totals and grand totals can be configured.
You can have them as "first", "last" or "none".

If you have multiple dimensions configured on one of the axis then the group totals will always be
visible when the group is collapsed no matter what you have configured for totals. That 
configuration will be used when the group is expanded.


## Renderers

Renderers are used to either style your cell or to format the output value.

Let's see how to easily style a cell. You need to define the renderer on the aggregate dimension.
    
    // ...
    aggregator: 'sum',
    renderer: function(v, meta, record){
        if(v > 40000){
            meta.style = "background-color: yellow;";
        }
        return Ext.util.Format.number(v, '0,000.00');
    }
    // ...

And here is the result.

{@img renderer.png}
    
Or you can have a complex one where you may want to style your cell if the sum is lower than the average
of some-other-field on the model.
    
    // ...
    aggregator: 'sum',
    renderer: function(v, meta, record, recordIndex, columnIndex, store, view){
        var grid = view.up('mzpivotgrid'),
            topItem = grid.getTopAxisItem(meta.column),
            leftItem = grid.getLeftAxisItem(record),
            result;
        
        if(topItem && leftItem){
            result = grid.getMatrix().results.get(leftItem.key, topItem.key);
            // if you already have the avg configured on another dimension just fetch the result
            // result.getValue('avg')
            
            // otherwise calculate the result
            result.calculateByFn('avg', 'some-other-field', Mz.aggregate.Aggregators.avg);
            
            if(v < result.getValue('avg')){
                meta.style = "background-color: yellow;";
            }
        }
        return Ext.util.Format.number(v, '0,000.00');
    }
    // ...

## Stateless

The pivot grid is stateless if you need it to be. Just set stateful true and set a stateId
like for any other component in Ext JS.

The state will save all dimension configs that you provided for the left, top and aggregate
and will also save the expanded or collapsed groups.

## Locked grids

Sometimes you may need to have the left axis columns fixed so that you can scroll only the
top axis generated columns. You can achieve this by setting enableLocking true on the pivot grid.