# Introduction

## What is a pivot table?

The Ext JS grid panel is perfect for displaying large sets of data, and it provides 
a large number of features of all kinds of data display. One of the additional kinds 
of data display that it doesn’t provide is a pivot grid. When it comes to reporting, 
a [pivot grid](http://en.wikipedia.org/wiki/Pivot_table#Explanation_of_a_pivot_table) 
is the way to go because it helps you organize and summarize data and create reports; 
and it enables users to make more informed decisions about your data.

## What is mzPivotGrid?

mzPivotGrid is a pivot table implementation for [Sencha Ext JS](http://www.sencha.com) framework.

Let’s imagine the following scenario. You have some sales data with the following fields: 
country, salesperson, order date, order amount and order ID. If you want to edit this data, 
you could easily use an Ext JS GridPanel with CellEditing or RowEditing plugins.

{@img GridPanel.png Grid panel}

What would you do if you had to answer the following questions?

* What are the order amounts of each salesperson?
* What are the order amounts of each salesperson in a specific country?
* How did salespeople perform in a specific year?


You could use mzPivotGrid to create those reports and here is how they would look:

{@img mzPivotGrid_report1.png What are the order amounts of each salesperson?}

{@img mzPivotGrid_report2.png What are the order amounts of each salesperson in a specific country?}

{@img mzPivotGrid_report3.png How did salespeople perform in a specific year?}

## Using mzPivotGrid

mzPivotGrid inherits the Ext JS Grid Panel component, so you can use most of its features 
you are already familiar with: column resizing, locking, cell renderers, row/cell events 
etc. The mzPivotGrid should be used when you want to use summation and pivot features 
that aren’t provided in the default GridPanel.

To break down the dataset into salespeople and years, you just have to configure the top and left axis:

    leftAxis: [{
        width:      80,
        dataIndex:  'salesperson',
        header:     'Salesperson'
    }],
    topAxis: [{
        dataIndex:  'year',
        header:     'Year',
        direction:  'ASC'
    }]


Multiple levels are supported, so if you need that you can just specify them in top and left axis. 

Now that you broke down the dataset on the top and left axis, it’s time to aggregate the cell 
values. Several kinds of aggregations are available including: sum, average, min, max, count 
etc. If these are not enough you can provide your own aggregation function.

    aggregate: [{
        measure:    'amount',
        header:     'Sales',
        aggregator: 'sum',
        align:      'right',
        width:      85,
        renderer:   Ext.util.Format.numberRenderer('0,000.00')
    },{
        measure:    'orderid',
        header:     'Qnt',
        aggregator: function(records, measure, matrix, rowGroupKey, colGroupKey) {
            // do your own algorithm
            return records.length;
        },
        align:      'right',
        width:      85,
        renderer:   Ext.util.Format.numberRenderer('0,000.00')
    }]
    
As you have probably noticed in the above example for some reports you could aggregate 
multiple data fields, say "sales" and "quantity".  You can easily achieve this by configuring 
all required aggregations.

{@img mzPivotGrid.png Pivot grid}


Let's go deeper into the pivot grid functionality in the following guides.