# Plugins

The pivot grid comes out of the box with the following plugins:

## Range editor

This plugin could be used to allow the user to edit the pivot grid results. The user has to
double click a pivot grid cell in order to open a window where he can choose what
type of update should be done. The following types of edit are available:

* percentage: the value provided is actually a percentage value that should be used to increase
the values on all records behind that cell.
* increment: the value provided will be added to the existing value on each record.
* overwrite: the value provided will be used to replace the existing value on each record.
* uniformly: the provided value will be distributed uniformly on all records.

The plugin provides two template methods that you can use: onBeforeRecordsUpdate and onAfterRecordsUpdate.

## Drill down

This plugin allows the user to drill down the pivot grid results. The user has to double click
a pivot grid cell and a new window is opened with a grid that lists all records behind that cell.

The grid available in that drill down window is customizable. You need to configure the "columns"
on the plugin same way you do with a normal Ext JS grid.

## Excel export

This plugin allows you to export the pivot grid results to a Microsoft Excel spreadsheet.
The function getExcelData on the plugin will return the xml data. The function has two parameters:

* onlyExpandedNodes: set to true if you want to export only the expanded groups
* includeTotals: set to false if you don't want to include the totals in the xml export

There are also a bunch of configs that could be set to style the xml export.

The demo available in this documentation uses Base64 data urls to download the generated
xml data as a file. This approach works only in Chrome and Firefox. To have a generic 
solution working in all browsers it's better to send the xml data to the server and 
send it back with the proper headers for a downloadable file.

You can have define a function in your pivot grid extension like this:

    // ...
    onExport: function() {
        var me = this,
            form = Ext.DomHelper.createDom({
                tag:    'form',
                action: 'url', // this is a URL on your backend that receives the xml content
                method: 'POST',
                children: [{
                    tag:    'input',
                    type:   'hidden',
                    name:   'filename',
                    value:  me.title
                },{
                    tag:    'input',
                    type:   'hidden',
                    name:   'content',
                    value:  encodeURIComponent(me.getExcelData())
                }]
            });
        form.submit();
    },
    getExcelData: function(){
        // let's assume that you defined your pluginId as "excelexport"
        return this.getPlugin('excelexport').getExcelData(false, true);
    }
    // ...

    
In a php script on your server side you have to do something like this:

    // ...
    $fileContent = $_POST['filename'] . '.xml';
    $fileContent = $_POST['content'];
    header('Content-Length: ' . strlen($fileContent));
    header("Content-Type:   application/vnd.ms-excel; charset=utf-8");
    header("Content-Disposition: attachment; filename=\"$fileName\"");
    header("Expires: 0");
    header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
    header("Cache-Control: private",false);
    echo urldecode($fileContent);
    // ...


## Configurator

This plugin will let the user easily configure the pivot grid with drag and drop. You can
define "fields" on this plugin as an array of available fields to drag and drop on
dimensions. If the "fields" config is empty then the plugin will automatically extract
all fields available on the store model if using a Local matrix.

If you decide to provide your own fields then define on each field some keys for:

* dataIndex: the field name on the model
* header: the field title displayed in the view
* any other dimension item config

