Ext.data.JsonP.api({"guide":"<h1 id='api-section-client-side-api'>Client side API</h1>\n<div class='toc'>\n<p><strong>Contents</strong></p>\n<ol>\n<li><a href='#!/guide/api-section-events'>Events</a></li>\n<li><a href='#!/guide/api-section-matrix-class'>Matrix class</a></li>\n</ol>\n</div>\n\n<h2 id='api-section-events'>Events</h2>\n\n<p>Most events fired by the matrix classes are relayed to the pivot grid with the prefix \"pivot\".</p>\n\n<h2 id='api-section-matrix-class'>Matrix class</h2>\n\n<h3 id='api-section-abstract-matrix'>Abstract matrix</h3>\n\n<p>The <a href=\"#!/api/Mz.aggregate.matrix.Abstract\">Abstract matrix</a> class is the one responsible to\nbuild the top and left axis items and to calculate the result for each pair left/top item.</p>\n\n<p>If you want to extend a matrix to do your own processing please have a look at the various\ntemplate methods that are available. Events are also fired if that's the preferred way.</p>\n\n<h3 id='api-section-local-matrix'>Local matrix</h3>\n\n<p>If you have a small to medium data set then you can use the <a href=\"#!/api/Mz.aggregate.matrix.Local\">Local matrix</a>\nclass to do all calculations in the browser.</p>\n\n<pre><code>Ext.create('<a href=\"#!/api/Mz.pivot.Grid\" rel=\"Mz.pivot.Grid\" class=\"docClass\">Mz.pivot.Grid</a>', {\n    // ...\n    matrixConfig: {\n        mztype:             'local',\n        store:              'YourStore',\n        recordsPerJob:      1000,\n        timeBetweenJobs:    2\n    }\n    // ...\n});\n</code></pre>\n\n<p>The Local matrix processes store records in multiple jobs to prevent browser to freeze when\nworking with a medium data set. You can optionally define how many records should\nbe processed per job and what is the delay between jobs (in miliseconds).</p>\n\n<p>If you don't want to set matrix specific configs you can directly attach a store to the\npivot grid since the default matrix configuration is Local.</p>\n\n<pre><code>Ext.create('<a href=\"#!/api/Mz.pivot.Grid\" rel=\"Mz.pivot.Grid\" class=\"docClass\">Mz.pivot.Grid</a>', {\n    // ...\n    store: 'YourStore'\n    // ...\n});\n</code></pre>\n\n<h3 id='api-section-remote-matrix'>Remote matrix</h3>\n\n<p>When dealing with large data sets, calculations in the browser can take a lot of time\nso it's better to use the <a href=\"#!/api/Mz.aggregate.matrix.Remote\">Remote matrix</a>. This one will serialize\nall configs and send them back to the server for remote calculations. It expects back\na JSON response in a specific format.</p>\n\n<pre><code>Ext.create('<a href=\"#!/api/Mz.pivot.Grid\" rel=\"Mz.pivot.Grid\" class=\"docClass\">Mz.pivot.Grid</a>', {\n    // ...\n    matrixConfig: {\n        mztype:     'remote',\n        url:        'http://your-backend-url',\n        timeout:    3000    // this is optional and it's used by the Ajax call\n    }\n    // ...\n});\n</code></pre>\n\n<h4 id='api-section-what-exactly-is-sent-to-the-server%3F'>What exactly is sent to the server?</h4>\n\n<p>leftAxis, topAxis and aggregate are arrays of <a href=\"#!/api/Mz.aggregate.dimension.Item\">dimension item objects</a>.\nThese arrays are serialized and sent as params to the Ajax call.</p>\n\n<pre><code>params = {\n    leftAxis:   leftAxis,\n    topAxis:    topAxis,\n    aggregate:  aggregate\n};\n// ...\nExt.Ajax.request({\n    // ...\n    url:        me.url,\n    timeout:    me.timeout,\n    jsonData:   params,\n    // ...\n});\n</code></pre>\n\n<p>Before doing the Ajax call additional params are collected via the event \"beforerequest\"\n(which is actually relayed to the grid as \"pivotbeforerequest\") or via the template\nmethod \"onBeforeRequest\".</p>\n\n<h4 id='api-section-what-format-has-the-json-response%3F'>What format has the JSON response?</h4>\n\n<p>When a <a href=\"#!/api/Mz.aggregate.dimension.Item\">dimension item</a> is added to the respective config\nan id is generated if this was not provided. This is is very important for the JSON response.</p>\n\n<pre><code>{\n    success: true,\n    leftAxis: [{\n        key:            '-1276511163',  // that's the crc32 of value \"Macromedia\"\n        value:          'Macromedia',\n        // this is the id of the dimension, the one that you provided or was generated\n        dimensionId:    'leftAxis1'\n    },{\n        // when multiple dimensions are provided then the result key should be formatted like this\n        key:            '-1276511163/243243',\n        value:          'Steve',\n        // this is the id of the dimension, the one that you provided or was generated\n        dimensionId:    'leftAxis2'\n    }],\n    topAxis: [{\n        // same like leftAxis\n    }],\n    results: [{\n        leftKey:    '-1276511163',\n        topKey:     '34535345435',\n        values: {\n            agg1:   4345.34,    // agg1 is the id of the aggregate dimension\n            agg2:   244         // agg2 is the id of the 2nd aggregate dimension defined\n        }\n    }]\n}\n</code></pre>\n\n<p>Basically you return an array of items for the leftAxis and topAxis and all results\nfor the left/top item pairs.</p>\n\n<p>Why is the key calculated as crc32? Because internally these keys are used with separators\nand no matter how fine you sanitize the strings you can end up with bugs in the process.</p>\n\n<p>\"#mzgrandtotal#\" is the key configured on the matrix for the grand total calculations.\nYou can define your own key on the matrix.grandTotalKey.</p>\n\n<p>If used on both leftKey and topKey it means is the grand total for both axis.</p>\n\n<p>When used for leftKey it means the grand total for columns for each topKey provided.</p>\n\n<p>When used for topKey it means the grand total for rows for each leftKey provided.</p>\n\n<h4 id='api-section-how-do-i-calculate-on-the-server%3F'>How do I calculate on the server?</h4>\n\n<p>You can either have a look at our php example in the examples folder or you can do your\nown implementation. There are various way to do that and in different programming languages.\nYou could even connect to an OLAP server and get back the results.</p>\n\n<p>If something fails on the server while doing your calculations you can send back\nsuccess: false and add any other information to your JSON response. The Remote matrix\nclass will recognize that the call failed and will fire the \"requestexception\" event (which\nis relayed to the pivot grid as \"pivotrequestexception\") and also call the template\nmethod \"onRequestException\".</p>\n","title":"Client side API"});