Ext.data.JsonP.functionality({"guide":"<h1 id='functionality-section-functionality'>Functionality</h1>\n<div class='toc'>\n<p><strong>Contents</strong></p>\n<ol>\n<li><a href='#!/guide/functionality-section-calculation-functions'>Calculation functions</a></li>\n<li><a href='#!/guide/functionality-section-sorting-results'>Sorting results</a></li>\n<li><a href='#!/guide/functionality-section-multiple-grand-totals'>Multiple grand totals</a></li>\n<li><a href='#!/guide/functionality-section-range-grouping'>Range grouping</a></li>\n<li><a href='#!/guide/functionality-section-server-side-calculations'>Server side calculations</a></li>\n<li><a href='#!/guide/functionality-section-filtering'>Filtering</a></li>\n<li><a href='#!/guide/functionality-section-buffered-renderer'>Buffered renderer</a></li>\n</ol>\n</div>\n\n<p>In the <a href=\"#!/guide/introduction\">Introduction guide</a> you were introduced to the basic\nfunctionality of the pivot grid. Below you will find more features available in this component.</p>\n\n<h2 id='functionality-section-calculation-functions'>Calculation functions</h2>\n\n<p>The following calculation methods are supported out of the box: sum, avg, min, max, count,\ngroupSumPercentage, groupCountPercentage, variance, varianceP, stdDev and stdDevP.</p>\n\n<p>You may ask yourself what is groupSumPercentage and groupCountPercentage?</p>\n\n<ul>\n<li>groupSumPercentage. If John sold items in USA and Germany you may want to see what percentage was\nsold to USA from the total sales. So it actually calculates the percentage of the current item\nsum out of the parent item sum.</li>\n<li>groupCountPercentage. Same as above except that count is used instead of sum.</li>\n</ul>\n\n\n<p>If none of these standard functions cover your needs then you can define your own function.</p>\n\n<pre><code>aggregate: [{\n    // ...\n    measure:    'field',\n    aggregator: function(records, measure, matrix, rowGroupKey, colGroupKey) {\n        // do your own algorithm\n        return records.length;\n    }\n    // ...\n}]\n</code></pre>\n\n<p>If you want your grid to be stateless then we strongly suggest to override <a href=\"#!/api/Mz.aggregate.Aggregators\">Mz.aggregate.Aggregators</a>\nto add your functions and use the function name in the aggregate dimension definition.</p>\n\n<pre><code>Ext.define('overrides.aggregate.Aggregators', {\n    override: '<a href=\"#!/api/Mz.aggregate.Aggregators\" rel=\"Mz.aggregate.Aggregators\" class=\"docClass\">Mz.aggregate.Aggregators</a>',\n\n    myOwnFn: function(records, measure, matrix, rowGroupKey, colGroupKey) {\n        // do your own algorithm\n        return records.length;\n    }\n});\n// and define your aggregate dimension like this\naggregate: [{\n    // ...\n    measure:    'field',\n    aggregator: 'myOwnFn'\n    // ...\n}]\n</code></pre>\n\n<h2 id='functionality-section-sorting-results'>Sorting results</h2>\n\n<p>When you define a dimension item you can provide some configs that will change the way the\nresults are sorted.</p>\n\n<ul>\n<li>sortable: do you want to sort the results or not? Default is true.</li>\n<li>direction: you may specify if you want the results to be sorted ASC or DESC. Default is ASC.</li>\n<li>caseSensitiveSort: is this is case sensitive sort or not? Default is true.</li>\n<li>sorterFn: you can even provide your own sorting algorithm.</li>\n<li>sortIndex: sometimes you may want to sort your results using the value of another field\non the record. Let's say you have one field \"month-name\" with values like Jan, Feb etc and\nanother field \"month-value\" with values like 1, 2 etc. It makes sense to have the results\nfrom \"month-name\" (dataIndex) and sort by \"month-value\" (sortIndex).</li>\n</ul>\n\n\n<h2 id='functionality-section-multiple-grand-totals'>Multiple grand totals</h2>\n\n<p>By default the pivot grid calculates grand totals on rows and you may choose to show that or not.\nIf you want to add multiple grand totals on rows it is possible in two ways:</p>\n\n<ul>\n<li>You can use the event \"pivotbuildtotals\" fired on the pivot grid. The event provides a parameter\nwhich is an array of grand total values including the default one. Each object in that array\nshould have a \"title\" and a \"values\" array that will be used to generate the new record.</li>\n<li>You can also extend one of the matrix classes and use the template method \"onBuildTotals\"\nto do the same thing as above.</li>\n</ul>\n\n\n<p>The new grand totals that you provide will be styled as the default grand total in the pivot grid.</p>\n\n<pre><code>// ...\nlisteners: {\n    pivotbuildtotals: function(matrix, totals){\n        var dataAvg = {},\n            dataMax = {};\n\n        Ext.Array.each(matrix.model, function(field){\n            var result,\n                agg;\n\n            if(field.col &amp;&amp; field.agg){\n                agg = matrix.aggregate.getByKey(field.agg);\n                result = matrix.results.get(matrix.grandTotalKey, field.col);\n                if(result &amp;&amp; agg){\n                    dataAvg[field.name] = result.calculateByFn('totalavg', agg.dataIndex, <a href=\"#!/api/Mz.aggregate.Aggregators-method-avg\" rel=\"Mz.aggregate.Aggregators-method-avg\" class=\"docClass\">Mz.aggregate.Aggregators.avg</a>);\n                    dataMax[field.name] = result.calculateByFn('totalmax', agg.dataIndex, <a href=\"#!/api/Mz.aggregate.Aggregators-method-max\" rel=\"Mz.aggregate.Aggregators-method-max\" class=\"docClass\">Mz.aggregate.Aggregators.max</a>);\n                }\n            }\n        });\n\n        totals.push({\n            title:  'Grand total (avg)',\n            values: dataAvg\n        },{\n            title:  'Grand total (max)',\n            values: dataMax\n        });\n    }\n}\n// ...\n</code></pre>\n\n<h2 id='functionality-section-range-grouping'>Range grouping</h2>\n\n<p>Let's say that you have on one of the axis results for years and you want to group them\nas 80', 90' and so on. You can achieve this in two ways:</p>\n\n<ul>\n<li>You can define a \"grouperFn\" on the dimension that will receive as argument the record\nand should return the group value (i.e. 80', 90' etc).</li>\n<li>You can define a new field on the source model that has a \"convert\" function and does the same thing\nas above.</li>\n</ul>\n\n\n<p>Here is a usage example for grouperFn:</p>\n\n<pre><code>leftAxis: [{\n    // ...\n    grouperFn: function(record){\n        var dataIndex = this.dataIndex;\n        if(record.get(dataIndex) &gt;= 1980 &amp;&amp; record.get(dataIndex) &lt; 1990) return \"80'\";\n        if(record.get(dataIndex) &gt;= 1990 &amp;&amp; record.get(dataIndex) &lt; 2000) return \"90'\";\n        return 'Rest';\n    }\n    // ...\n}]\n</code></pre>\n\n<h2 id='functionality-section-server-side-calculations'>Server side calculations</h2>\n\n<p>The product comes with two types of calculations:</p>\n\n<ul>\n<li>Local calculations in the browser by using the <a href=\"#!/api/Mz.aggregate.matrix.Local\">Local matrix</a></li>\n<li>Remote calculations on the server by using the <a href=\"#!/api/Mz.aggregate.matrix.Remote\">Remote matrix</a></li>\n</ul>\n\n\n<p>Both are explained in the <a href=\"#!/guide/api\">Client side API guide</a>.</p>\n\n<h2 id='functionality-section-filtering'>Filtering</h2>\n\n<p>There are two types of filters available:</p>\n\n<ul>\n<li>Label filter: it allows you to filter the results by looking at the values generated for\ntop or left axis results. i.e. begins with, does not begin with, ends with etc.</li>\n<li>Value filter: it allows you to filter the results by looking at the values calculated for each\ntop/left axis pair. i.e. equals to, greater than, top 10 items, top 10 percent, top 10 sum etc</li>\n</ul>\n\n\n<p>The filter needs to be configured on a dimension item of the left or top axis.</p>\n\n<pre><code>leftAxis: [{\n    // ...\n    filter: {\n        mztype:      'value',\n        type:       <a href=\"#!/api/Mz.aggregate.filter.Value-static-property-TypeTop10\" rel=\"Mz.aggregate.filter.Value-static-property-TypeTop10\" class=\"docClass\">Mz.aggregate.filter.Value.TypeTop10</a>,\n        topOrder:   'top',\n        topType:    'sum',\n        value:      9500,\n        dimensionId:'agg2'\n    }\n    // ...\n}]\n</code></pre>\n\n<p>To find out more have a look at the available filter classes (Mz.aggregate.filter.*).</p>\n\n<h2 id='functionality-section-buffered-renderer'>Buffered renderer</h2>\n\n<p>When the calculations are ready inside the pivot grid there could be thousand of records available\nin the pivot store. This may be a problem for grid rendering but fortunately the Ext JS\nframework has a BufferedRenderer plugin available since version 4.2.0. In version 5.0.x this\nplugin is used by the grid panel by default.</p>\n\n<p>This plugin allows users to scroll through thousand of records without the performance penalties\nof rendering all the records on screen at once.</p>\n\n<p>This is how you can use it:</p>\n\n<pre><code>var pivot = Ext.create('<a href=\"#!/api/Mz.pivot.Grid\" rel=\"Mz.pivot.Grid\" class=\"docClass\">Mz.pivot.Grid</a>', {\n    // ...\n    plugins: {\n        ptype: 'bufferedrenderer',\n        trailingBufferZone: 20,  // Keep 20 rows rendered in the table behind scroll\n        leadingBufferZone: 50   // Keep 50 rows rendered in the table ahead of scroll\n    },\n    // ...\n});\n</code></pre>\n","title":"Functionality"});